<template>
  <div class="bbsl-common-page">
    <div class="bbsl-table-search">
      <el-form v-model="queryParam" label-width="auto">
        <el-row :gutter="10">
          <el-col :span="5">
            <el-form-item label="签订单位名称">
              <el-input clearable placeholder="请输入签订单位名称" v-model="querys[0].value" />
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="单位类型" prop="companyType">
              <el-select v-model="querys[1].value" size="small" placeholder="请选择单位类型" clearable>
                <el-option v-for="item in zhgldwlxList" :key="item.value" :label="item.name" :value="item.value" />
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="签订年度">
              <el-date-picker v-model="querys[2].value" type="year" value-format="yyyy" placeholder="请选择签订年度"
                style="width:100%;" />
              <!-- <el-input clearable placeholder="请输入签订年度" v-model="querys[2].value" /> -->
            </el-form-item>
          </el-col>
          <el-col :span="4">
            <el-button type="primary" icon="el-icon-search" @click="handleSearch">搜索</el-button>
            <el-button icon="el-icon-refresh" @click="handleReset">重置</el-button>
          </el-col>
        </el-row>



        <!-- <el-form-item label="签订日期">
          <el-date-picker
            v-model="querys[3].value"
            clearable
            type="daterange"
            range-separator="至"
            start-placeholder="开始日期"
            end-placeholder="结束日期"
            value-format="yyyy-MM-dd"
          ></el-date-picker>
        </el-form-item> -->
        <!-- <el-form-item label="签定日期">
					<el-input clearable placeholder="请输入签定日期" v-model="querys[3].value" />
				</el-form-item> -->
        <el-form-item>

        </el-form-item>
      </el-form>
    </div>
    <div class="bbsl-table-content" ref="contentPanel">
      <div class="bbsl-btn-content" ref="btnPanel">
        <el-button icon="el-icon-plus" type="primary" @click="handleAdd">新增</el-button>
        <el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
          <el-button slot="reference" :disabled="!multipleSelection.length" icon="el-icon-delete" type="danger"
            style="margin-left: 10px">删除</el-button>
        </el-popconfirm>
      </div>
      <el-table border size="mini" v-loading="loading" ref="multipleSelection" :data="tableData"
        :style="{ width: '100%' }" :max-height="tableMaxHeight" :cell-style="{ 'text-align': 'center' }"
        :header-cell-style="{ 'text-align': 'center' }" @row-dblclick="handleDbClick"
        @selection-change="handleSelectionChange">
        <el-table-column type="selection" width="55"></el-table-column>
        <el-table-column fixed type="index" width="55" label="序号"></el-table-column>
        <el-table-column fixed sortable prop="signYear" label="签订年度" show-overflow-tooltip></el-table-column>
        <el-table-column fixed prop="companyTypeName" label="单位类型" show-overflow-tooltip>
        </el-table-column>
        <el-table-column fixed prop="signCompanyName" label="签订单位名称" show-overflow-tooltip></el-table-column>
        <el-table-column fixed prop="signer" label="签定人" show-overflow-tooltip></el-table-column>
        <el-table-column fixed sortable prop="signDate" label="签定日期" show-overflow-tooltip></el-table-column>
      </el-table>
      <el-pagination align="right" background class="bbsl-pagination" ref="paginationPanel"
        @size-change="handleSizeChange" @current-change="handleCurrentChange" :current-page="queryParam.pageBean.page"
        :page-sizes="[20, 30, 40, 50]" :page-size="queryParam.pageBean.pageSize"
        layout="total, sizes, prev, pager, next, jumper" :total="total"></el-pagination>
    </div>
    <CmgtSaftyLiabilityFormDialog ref="formModal"></CmgtSaftyLiabilityFormDialog>
  </div>
</template>

<script>
import { TableMixin } from '@/mixins/tableMixin'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import dictContracts from '@/components/dict/DictSelectUtils.js'

import CmgtSaftyLiabilityApi from '@/views/Manage/saftyPlan/api/CmgtSaftyLiabilityApi'
import CmgtSaftyLiabilityFormDialog from '@/views/Manage/saftyPlan/components/CmgtSaftyLiabilityFormDialog'

export default {
  name: 'CmgtSaftyLiabilityManage',
  components: {
    CmgtSaftyLiabilityFormDialog
  },
  mixins: [TableMixin],
  data() {
    return {
      url: {
        delete: '/manager/cmgtSaftyLiability/delete'
      },
      querys: [
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'sign_company_name_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'company_type_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'sign_year_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'BETWEEN',
          parentGroup: '',
          property: 'sign_date_',
          relation: 'AND',
          value: ''
        },
      ],
      StshowFormDias: false,
      fuelTypes: [],
      zhgldwlxList: []
    }
  },
  created() {
    this.zhgldwlxList = dictUtils.getDictItemsFromCache('zhgl-dwlx')
  },
  mounted() { },
  methods: {
    // 重置
    clearQuerys() {
      this.querys[0].value = ''
      this.querys[1].value = ''
      this.querys[2].value = ''
      this.querys[3].value = ''
    },
    // 获取list
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      if (this.querys[2].value) {
        this.queryParam.querys.push(this.querys[2])
      }
      if (this.querys[3].value) {
        this.queryParam.querys.push(this.querys[3])
      }
      CmgtSaftyLiabilityApi.loadCmgtSaftyLiability(this.queryParam, res => {
        //console.log(res, 'res')
        this.total = res.total
        this.tableData = res.rows
        this.tableData.forEach(item => {
          this.zhgldwlxList.forEach(val => {
            if (item.companyType == val.value) {
              item['companyTypeName'] = val.name
            }
          })
        })

        this.$set(this.tableData)
        this.loading = false
      })
    },
    // 修改
    handleUpdate(row) {
      console.log(row.id)
      this.$refs.formModal.Update(row)
    },
    // 关联设备
    // handleClick(item) {
    //   console.log(item.id)
    //   this.StshowFormDias = true
    // },
    closeStshowForm() {
      this.StshowFormDias = false
    }
  }
}
</script>
<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}
</style>
